@@ -34,7 +34,10 @@ public Q_SLOTS:
     void switchFullscreen(bool on) override;
 
 protected:
-    bool eventFilter(QObject *obj, QEvent *event) override;
+    void handleKeyEvent(QKeyEvent *event) override;
+    void handleWheelEvent(QWheelEvent *event) override;
+    void handleMouseEvent(QMouseEvent *event) override;
+    void handleLocalClipboardChanged(const QMimeData *data) override;
 
 private:
     TestHostPreferences *m_hostPreferences;
